==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Btooth_/Econfiguration_/Pconfiguration_/Fsbit_/State.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit<CH>:STATe \n
		Enables / disables features, related to bit numbers 0 to 27 for the used feature set. See also Table 'Link layer
		features: Bit number and feature'. Information is transmitted via LL_FEATURE_REQ, LL_FEATURE_RSP, LL_SLAVE_FEATURE_REQ. \n
			:param state: 0| 1| OFF| ON
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fsbit')"""
		param = Conversions.bool_to_str(state)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit{channel_cmd_val}:STATe {param}')

	def get(self, channel=repcap.Channel.Default) -> bool:
		"""[SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit<CH>:STATe \n
		Enables / disables features, related to bit numbers 0 to 27 for the used feature set. See also Table 'Link layer
		features: Bit number and feature'. Information is transmitted via LL_FEATURE_REQ, LL_FEATURE_RSP, LL_SLAVE_FEATURE_REQ. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fsbit')
			:return: state: 0| 1| OFF| ON"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit{channel_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Btooth_/Econfiguration_/Pconfiguration_/Fsbit_/State.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit<CH>:STATe \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.fsbit.state.set(state = False, channel = repcap.Channel.Default) \n
		Enables / disables features, related to bit numbers 0 to 27 for the used feature set. See also Table 'Link layer
		features: Bit number and feature'. Information is transmitted via LL_FEATURE_REQ, LL_FEATURE_RSP, LL_SLAVE_FEATURE_REQ. \n
			:param state: 0| 1| OFF| ON
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fsbit')"""
		param = Conversions.bool_to_str(state)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit{channel_cmd_val}:STATe {param}')

	def get(self, channel=repcap.Channel.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit<CH>:STATe \n
		Snippet: value: bool = driver.source.bb.btooth.econfiguration.pconfiguration.fsbit.state.get(channel = repcap.Channel.Default) \n
		Enables / disables features, related to bit numbers 0 to 27 for the used feature set. See also Table 'Link layer
		features: Bit number and feature'. Information is transmitted via LL_FEATURE_REQ, LL_FEATURE_RSP, LL_SLAVE_FEATURE_REQ. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fsbit')
			:return: state: 0| 1| OFF| ON"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:FSBit{channel_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)
